#
# spec file for package python-zope.security
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2013 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-zope.security%{psuffix}
Version:        5.1.1
Release:        bp155.2.11
Summary:        Zope Security Framework
License:        ZPL-2.1
Group:          Development/Languages/Python
URL:            https://www.python.org/pypi/zope.security
Source0:        https://files.pythonhosted.org/packages/source/z/zope.security/zope.security-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module zope.interface}
BuildRequires:  %{python_module zope.proxy-devel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pytz
Requires:       python-zope.component
Requires:       python-zope.configuration
Requires:       python-zope.i18nmessageid
Requires:       python-zope.interface
Requires:       python-zope.location
Requires:       python-zope.proxy >= 4.3.0
Requires:       python-zope.schema >= 4.2.0
%if %{with test}
BuildRequires:  %{python_module BTrees}
BuildRequires:  %{python_module zope.component}
BuildRequires:  %{python_module zope.configuration}
BuildRequires:  %{python_module zope.location}
BuildRequires:  %{python_module zope.proxy >= 4.3.0}
BuildRequires:  %{python_module zope.schema >= 4.2.0}
BuildRequires:  %{python_module zope.security = %{version}}
BuildRequires:  %{python_module zope.testing}
BuildRequires:  %{python_module zope.testrunner}
%endif
%python_subpackages

%description
The Security framework provides a generic mechanism to implement security
policies on Python objects.

%prep
%setup -q -n zope.security-%{version}
rm -rf *.egg-info

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%endif

%if %{with test}
%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} %{_bindir}/zope-testrunner-%{$python_bin_suffix} -vvv --test-path src
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitearch}/*
%endif

%changelog
* Thu Apr  2 2020 pgajdos@suse.com
- version update to 5.1.1
  - Ensure all objects have consistent interface resolution orders (if
    all dependencies are up-to-date). See `issue 71
    <https://github.com/zopefoundation/zope.security/issues/71>`_.
* Mon Mar  9 2020 pgajdos@suse.com
- version update to 5.1.0
  - Let proxied interfaces be iterated on Python 3. This worked on
    Python 2, but raised ``ForbiddenAttribute`` an Python 3. See
    `zope.interface issue 141 <https://github.com/zopefoundation/zope.interface/issues/141>`_.
  - Allow to use a common Sphinx version for Python 2 and 3.
* Tue Jan 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 5.0
  * Drop support for Python 3.4.
  * Add support for Python 3.8.
  * Properly declare dependency on zope.schema >= 4.2.0, introduced in zope.security 4.2.1.
  * Fix dict item view iteration on PyPy3 7.x.
* Mon Apr  8 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.3.1
  * Fix the decimal.Decimal checker, __truediv__ was missing
    causing ForbiddenAttribute on a ProxyFactory(Decimal('1')) / 1
    operation
  4.3.0
  * Add the interface ISystemPrincipal and make
    zope.security.management.system_user a regular object that
    implements this interface.
  4.2*
  * Add support for Python 3.7.
  * Make the pure-Python proxy on Python 2 not check permissions for
    __unicode__ just like the C implementation. Note that __str__ is
    checked for both implementations on both Python 2 and 3, but if
    there is no __unicode__ method defined, Python 2’s automatic
    fallback to __str__ is not checked when unicode is called.
  * Fix the default values for Permission fields title and
    description under Python 2.
  * Change the IPermission.id from Text (unicode) to a
    NativeStringLine.
  * Fix the extremely rare potential for a crash when the C
    extensions are in use.
  * The pure-Python proxy didn’t propagate TypeError from __repr__
    and __str__ like the C implementation did.
  * Iteration of zope.interface.providedBy() is now allowed by
    default on all versions of Python.
  * Drop support for Python 3.3.
  * Respect PURE_PYTHON at runtime.
  * Fix watching checkers (ZOPE_WATCH_CHECKERS=1) in pure-Python
    mode.
- Fix tests using multibuild (can be dropped in the future).
* Sun Jul 16 2017 aloisio@gmx.com
- Update to version 4.1.1
  * Fix issue 23: iteration of collections.OrderedDict and its
    various views is now allowed by default on all versions of
    Python.
  * As a further fix for issue 20, iteration of BTree itself is
    now allowed by default.
  4.1.0:
  * When testing PURE_PYTHON environments under tox, avoid
    poisoning the user’s global wheel cache.
  * Drop support for Python 2.6 and 3.2.
  * Add support for Python 3.5 and 3.6.
  * Fix issue 20: iteration of pure-Python BTrees.items(), and
    also creating a list from BTrees.items() on Python 3. The same
    applies for keys() and values().
  4.0.3:
  * Fix iteration over security proxies in Python 3 using the
    pure-Python implementation.
  4.0.2:
  * Fix compatibility with zope.proxy 4.1.5 under PyPy.
  * Fix the very first call to removeSecurityProxy returning
    incorrect results if given a proxy under PyPy.
  4.0.1:
  * Add support for Python 3.4.
- Split docs and tests into separate -doc package to avoid
  dependency loop and other zope-related problems, see
  (gh#/zopefoundation/zope.proxy#18)
- Converted to single-spec
* Tue Jul 30 2013 hpj@urpla.net
- don't ship *.c files
* Mon Jul 29 2013 hpj@urpla.net
- version 4.0.0: initial build
